#
# spec file for package swww
#
# Copyright (c) 2023 SUSE LLC
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           swww
Version:        0.8.1
Release:        bp156.1.8
Summary:        Wallpaper daemon for Wayland
License:        GPL-3.0-only
URL:            https://github.com/Horus645/swww
Source0:        %{name}-%{version}.tar
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  rust+cargo >= 1.64.0
BuildRequires:  scdoc
BuildRequires:  zstd
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(xkbcommon)

%description
swww is a wallpaper daemon for Wayland that is controlled
at runtime. It uses LZ4 compression for frame animations
for animated wallpapers.

%package        bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
BuildArch:      noarch

%description    bash-completion
Bash command-line completion support for %{name}.

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       zsh
BuildArch:      noarch

%description    zsh-completion
Zsh command-line completion support for %{name}.

%prep
%autosetup -a1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
./doc/gen.sh
%{cargo_build}

%install
install -Dm644 -T completions/swww.bash  %{buildroot}%{_datadir}/bash-completion/completions/swww
install -Dm644 -T completions/swww.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/swww.fish
install -Dm644 -T completions/_swww %{buildroot}%{_datadir}/zsh/site-functions/_swww
install -Dm644 -t %{buildroot}%{_mandir}/man1 doc/generated/swww*1
%{cargo_install}

# For the daemon
unset LIBSSH2_SYS_USE_PKG_CONFIG && \
if [[ -z $RUSTC_WRAPPER ]]; then CARGO_AUDITABLE="auditable" ; fi && \
%{__cargo} $CARGO_AUDITABLE install \
%{__cargo_common_opts} \
--offline \
--no-track \
--root=%{buildroot}%{_prefix} \
--path daemon

%files
%{_bindir}/swww
%{_bindir}/swww-daemon
%license LICENSE
%doc CHANGELOG.md README.md
%_mandir/man1/%{name}*.1%{?ext_man}

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/swww

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/swww.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_swww

%changelog
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Tue Jul 25 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.8.1:
  * fix sending images in quick succession
  * remember to set exclusive zone to -1
  * remove condvar from wallpaper
  * overhaul transition waiting mechanism
  * nuke gif processing pipeline
  * load cache on `swww init`
  * add a `none` transition
  * fix clear exiting daemon
  * Version 0.8.0
  * update CHANGELOG and man-pages
  * fix rebase error
  * spell check example scripts
  * fix fade transition
  * fix failing test
  * update changelog and todo
  * stop using signals hack to wake main thread
  * cache only tries loading gifs from correct version
  * fix deadlock when resizing monitor
  * put Arc<SlotPool> in wallpaper struct
  * name threads for better errors
  * Rework syncing animations between monitors
  * bump dependencies - new rust version
  * reimplement cache with a different strategy
  * fix scaling images
  * fix deadlock on `clear` with on-going animation
  * update documentation
  * reimplement syncing animations
  * fix wrong transmute
  * rename utils::communication -> utils::ipc
  * use Box instead of Vec in all communication types
  * better values for step when falling back to simple
  * fix animation preventing transition to begin
  * change serde for rkyv for serialization
  * compress animation frames in a pipeline
  * only lock what is necessary
  * Rename daemon's modules and structs for clarity
  * Sending RGB instead of RGBA images
  * nuke cache
  * syncronizing with condvars
  * fix canvas pool not being ready
  * fix crash when changing scale factor
  * rename modules and fix cache import
  * animations working
  * transitions working
  * begin implementation - working for static images
  * add to docs
  * add doc for --invert-y
  * fix invert_y for percentage values
  * impl invert_y flag
  * fix spelling
  * feat: add option to resize image to fit screen instead of cropping
  * fix: don't skew images padded from odd widths
  * fix
  * add doc
  * readd `simple` and rename to `fade`
  * cargo fmt && cargo clippy
  * re add fallback
  * impl beziers for simple
* Thu Jun  8 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies. Resolves CVE and bsc#1212009.
* Sun May  7 2023 socvirnyl.estela@gmail.com
- Update to version 0.7.3:
  * Log error instead of returning
  * Send status update to systemd when daemon has initialized
  * split outputs with ,
  * bump dependencies
  * start animation right after finishing transition
  * better spread of different bytes
  * create benchmarks for compression functions
  * update dependencies
  * stop-gag zip_eq panic on slices of unequal size
  * check if cache dir is actually a dir
  * use std::thread::scope for gif frames
  * wait until all gif's frames are ready
  * `--transition-step` with `simple` saner default
  * fix: Missing `/` when using `$HOME/.cache/swww`
* Sun May  7 2023 Jan-Luca Kiok <opensuse-packages@jlk.one>
- Build and package man pages
- Add cargo version requirement
* Sat Mar 18 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix specfile.
- Fix installation of swww-daemon.
* Fri Mar 10 2023 socvirnyl.estela@gmail.com
- Update to version 0.7.2:
  * prepare 0.7.2 release
  * update dependencies
  * man-pages (#84)
  * Sync animations (#82)
  * update changelog
  * ignore integration_tests by default
  * cache the images to reload them on startup (#80)
  * prepare 0.7.1 release
  * update dependencies
  * cargo clippy and style
  * update CHANGELOG.md
  * fix integration_tests calling incorrect daemon bin
  * add ability to use screen cords instead of percentages in `--transition-pos` (#71)
  * typo: pipw -> pipe
  * fix reading image from stdin (don't cannonicalize)
  * document `--no_resize` and `--fill_color` args
  * fix `swww` query not returning correct image
  * change the version in Cargo.toml
* Mon Jan 30 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.7.0
  * update changelog
  * nuke `fix_zsh_completion.sh`
  * bump dependencies
  * inline printed variables where possible
  * use `with_guessed_format` to detect image type
  * [utils/comp_decomp] handle scale factor reduction
  * new transition: wave (#66)
  * [client] use scaling when sending images
* Mon Jan 23 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 0.6.0+git18:
  * fix panic on gif with identical frames
  * implement --no-resize for animated gifs
  * implement --no-resize option
  * fix insane problem introduced by 29e2683
  * change default transition step value
  * implement reading image from stdin
* Mon Oct 10 2022 Jan Engelhardt <jengelh@inai.de>
- Trim excess marketing from description
* Sun Oct  9 2022 socvirnyl.estela@gmail.com
- Update to version 0.4.3+git14:
  * bump dependencies (clap went from 3.x to 4.x)
  * Render the cursor on an empty desktop
  * Fixed a typo
  * This protocol is not actually required / used
  * Use safer type conversion
  * docs: Put type in backticks
  * Formatting
  * Simplify closure that just calls a function
  * Avoid copying data unnecessarily
  * Remove unnecessary Option
- Install shell completions for zsh, bash, and fish
* Sun Oct  9 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for swww version 0.4.3
